@@ -7,4 +7,7 @@ def unknown_method(r: Request):
     return (405, f"Method {r.method} is not supported.")
 
 def ratelimited_default(r: Request):
-    return (429, "Too many requests from the same client.")
\ No newline at end of file
+    return (429, "Too many requests from the same client.")
+
+def blocked_default(r: Request):
+    return (403, "Your client has been blocked.")
\ No newline at end of file
